@@ -3,7 +3,7 @@ package Net::Subnets;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 sub new { bless( {} ) }
 
@@ -47,7 +47,7 @@ Net::Subnets - Match large lists of IP addresses against many CIDR subnets
 
     use Net::Subnets;
     my $sn = Net::Subnets->new;
-    $sn->subnets(\@addresses);
+    $sn->subnets(\@subnets);
     if (my $subnetref = $sn->check(\$address)) {
         ...
     }
@@ -72,6 +72,26 @@ The following functions are provided by this module:
         It takes a scalar reference and returns a scalar reference to
         the first matching CIDR subnet.
 
+This is a simple and efficient example:
+
+    use Net::Subnets;
+
+    my @subnets   = qw(10.0.0.0/24 10.0.1.0/24);
+    my @addresses = qw(10.0.0.1 10.0.1.2 10.0.3.1);
+
+    my $sn = Net::Subnets->new;
+    $sn->subnets( \@subnets );
+    my $results;
+    foreach my $address (@addresses) {
+        if ( my $subnetref = $sn->check( \$address ) ) {
+            $results .= "$address: $$subnetref\n";
+        }
+        else {
+            $results .= "$address: not found\n";
+        }
+    }
+    print($results);
+
 =head1 AUTHOR
 
 Sebastian Riedel (sri@cpan.org),
